==> haskell-doctest-0.20.1-78.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest
version:              0.20.1
visibility:           public
id:                   doctest-0.20.1-IBEt6ufTjVnA8ADVyGayUK
key:                  doctest-0.20.1-IBEt6ufTjVnA8ADVyGayUK
license:              MIT
copyright:            (c) 2009-2022 Simon Hengel
maintainer:           quasicomputational@gmail.com, Andreas Abel
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/doctest#readme
synopsis:             Test interactive Haskell examples
description:
    `doctest` is a tool that checks [examples](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810775744)
    and [properties](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810771856)
    in Haddock comments.
    It is similar in spirit to the [popular Python module with the same name](https://docs.python.org/3/library/doctest.html).

    Documentation is at <https://github.com/sol/doctest#readme>.

category:             Testing
abi:                  02fef2914029f60195e95206665a4b20
exposed:              True
exposed-modules:      Test.DocTest
hidden-modules:
    Extract GhcUtil Info Interpreter Location Options PackageDBs Parse
    Property Run Runner Runner.Example Util
    Language.Haskell.GhciWrapper Paths_doctest

import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-0.20.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-0.20.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest
hs-libraries:         HSdoctest-0.20.1-IBEt6ufTjVnA8ADVyGayUK
depends:
    base-4.16.4.0 base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    code-page-0.2.1-2Ge3Prwpi0K5qObDyqbdK0 deepseq-1.4.6.1
    directory-1.3.6.2 exceptions-0.10.4 filepath-1.4.2.2 ghc-9.2.8
    ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp process-1.6.16.0
    syb-0.7.2.4-3l4i7x4UWHaFMYIEmP3T6l transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html:         /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-0.20.1-82.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest
version:              0.20.1
visibility:           public
id:                   doctest-0.20.1-7RbJRjQ6BbdDSBp8bDqxss
key:                  doctest-0.20.1-7RbJRjQ6BbdDSBp8bDqxss
license:              MIT
copyright:            (c) 2009-2022 Simon Hengel
maintainer:           quasicomputational@gmail.com, Andreas Abel
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/doctest#readme
synopsis:             Test interactive Haskell examples
description:
    `doctest` is a tool that checks [examples](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810775744)
    and [properties](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810771856)
    in Haddock comments.
    It is similar in spirit to the [popular Python module with the same name](https://docs.python.org/3/library/doctest.html).

    Documentation is at <https://github.com/sol/doctest#readme>.

category:             Testing
abi:                  fa30992e4f04ddbb9ccc6f9d7900b7a9
exposed:              True
exposed-modules:      Test.DocTest
hidden-modules:
    Extract GhcUtil Info Interpreter Location Options PackageDBs Parse
    Property Run Runner Runner.Example Util
    Language.Haskell.GhciWrapper Paths_doctest

import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-0.20.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-0.20.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest
hs-libraries:         HSdoctest-0.20.1-7RbJRjQ6BbdDSBp8bDqxss
depends:
    base-4.16.4.0 base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    code-page-0.2.1-2Ge3Prwpi0K5qObDyqbdK0 deepseq-1.4.6.1
    directory-1.3.6.2 exceptions-0.10.4 filepath-1.4.2.2 ghc-9.2.8
    ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp process-1.6.16.0
    syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html:         /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
